Merged
Conversation
Semver Impact of This PR🟢 Patch (bug fixes) 📋 Changelog PreviewThis is how your changes will appear in the changelog. New Features ✨
Internal Changes 🔧
🤖 This preview updates automatically when you update the PR. |
f90d384 to
502c808
Compare
502c808 to
85408dc
Compare
7bde325 to
fdac9ae
Compare
There was a problem hiding this comment.
Cursor Bugbot has reviewed your changes and found 1 potential issue.
Autofix Details
Bugbot Autofix prepared a fix for the issue found in the latest run.
- ✅ Fixed: Copy-pasted Node version skip is wrong for Vite 4
- Fixed vite4/utils.ts to check Node <14 instead of <20, and corrected vite7/utils.ts comment from 'Vite v8' to 'Vite v7'.
Or push these changes by commenting:
@cursor push 5b62142bc5
Preview (5b62142bc5)
diff --git a/packages/integration-tests-next/fixtures/vite7/utils.ts b/packages/integration-tests-next/fixtures/vite7/utils.ts
--- a/packages/integration-tests-next/fixtures/vite7/utils.ts
+++ b/packages/integration-tests-next/fixtures/vite7/utils.ts
@@ -26,7 +26,7 @@
// Clear the output directory before running the test
rmSync(outDir, { recursive: true, force: true });
- // Vite v8 requires Node 20+
+ // Vite v7 requires Node 20+
if (NODE_MAJOR_VERSION < 20) {
// eslint-disable-next-line @typescript-eslint/no-empty-function
vitestTest.skip(testName);This Bugbot Autofix run was free. To enable autofix for future PRs, go to the Cursor dashboard.
chargome
reviewed
Mar 25, 2026
Collaborator
Author
chargome
approved these changes
Mar 30, 2026
This was referenced Apr 7, 2026
renovate Bot
added a commit
to andrei-picus-tink/auto-renovate
that referenced
this pull request
Apr 15, 2026
| datasource | package | from | to | | ---------- | ------------------- | ----- | ----- | | npm | @sentry/vite-plugin | 5.1.1 | 5.2.0 | ## [v5.2.0](https://github.com/getsentry/sentry-javascript-bundler-plugins/blob/HEAD/CHANGELOG.md#520) ##### New Features ✨ - (core) Pass `mapDir` to `rewriteSourcesHook` by [@chargome](https://github.com/chargome) in [#908](getsentry/sentry-javascript-bundler-plugins#908) - Use `crypto.randomUUID` rather than `uuid` by [@timfish](https://github.com/timfish) in [#892](getsentry/sentry-javascript-bundler-plugins#892) ##### Bug Fixes 🐛 - (core) Conditionally add tracing headers by [@chargome](https://github.com/chargome) in [#907](getsentry/sentry-javascript-bundler-plugins#907) - (e2e-tests) Pin axios to 1.13.5 to avoid compromised 1.14.1 by [@andreiborza](https://github.com/andreiborza) in [#906](getsentry/sentry-javascript-bundler-plugins#906) - (rollup) Make rollup an optional peer dependency by [@andreiborza](https://github.com/andreiborza) in [#913](getsentry/sentry-javascript-bundler-plugins#913) - Add missing webpack5 entrypoint in webpack-plugin by [@brunodccarvalho](https://github.com/brunodccarvalho) in [#905](getsentry/sentry-javascript-bundler-plugins#905) ##### Internal Changes 🔧 - (deps) Bump vulnerable webpack version by [@chargome](https://github.com/chargome) in [#909](getsentry/sentry-javascript-bundler-plugins#909) - (tests) Use deterministic debugids by [@chargome](https://github.com/chargome) in [#912](getsentry/sentry-javascript-bundler-plugins#912) - Add esbuild integration tests by [@timfish](https://github.com/timfish) in [#911](getsentry/sentry-javascript-bundler-plugins#911) - Vite integration tests by [@timfish](https://github.com/timfish) in [#899](getsentry/sentry-javascript-bundler-plugins#899) - Webpack integration tests by [@timfish](https://github.com/timfish) in [#904](getsentry/sentry-javascript-bundler-plugins#904) - Isolate integration test package installs by [@timfish](https://github.com/timfish) in [#902](getsentry/sentry-javascript-bundler-plugins#902) - Pin GitHub Actions to full-length commit SHAs by [@joshuarli](https://github.com/joshuarli) in [#900](getsentry/sentry-javascript-bundler-plugins#900) - Rollup integration tests by [@timfish](https://github.com/timfish) in [#897](getsentry/sentry-javascript-bundler-plugins#897) - New integration tests by [@timfish](https://github.com/timfish) in [#896](getsentry/sentry-javascript-bundler-plugins#896) - Remove lerna by [@timfish](https://github.com/timfish) in [#895](getsentry/sentry-javascript-bundler-plugins#895) - Migrate to Vitest by [@timfish](https://github.com/timfish) in [#894](getsentry/sentry-javascript-bundler-plugins#894)
renovate Bot
added a commit
to andrei-picus-tink/auto-renovate
that referenced
this pull request
Apr 15, 2026
| datasource | package | from | to | | ---------- | ------------------- | ----- | ----- | | npm | @sentry/vite-plugin | 5.1.1 | 5.2.0 | ## [v5.2.0](https://github.com/getsentry/sentry-javascript-bundler-plugins/blob/HEAD/CHANGELOG.md#520) ##### New Features ✨ - (core) Pass `mapDir` to `rewriteSourcesHook` by [@chargome](https://github.com/chargome) in [#908](getsentry/sentry-javascript-bundler-plugins#908) - Use `crypto.randomUUID` rather than `uuid` by [@timfish](https://github.com/timfish) in [#892](getsentry/sentry-javascript-bundler-plugins#892) ##### Bug Fixes 🐛 - (core) Conditionally add tracing headers by [@chargome](https://github.com/chargome) in [#907](getsentry/sentry-javascript-bundler-plugins#907) - (e2e-tests) Pin axios to 1.13.5 to avoid compromised 1.14.1 by [@andreiborza](https://github.com/andreiborza) in [#906](getsentry/sentry-javascript-bundler-plugins#906) - (rollup) Make rollup an optional peer dependency by [@andreiborza](https://github.com/andreiborza) in [#913](getsentry/sentry-javascript-bundler-plugins#913) - Add missing webpack5 entrypoint in webpack-plugin by [@brunodccarvalho](https://github.com/brunodccarvalho) in [#905](getsentry/sentry-javascript-bundler-plugins#905) ##### Internal Changes 🔧 - (deps) Bump vulnerable webpack version by [@chargome](https://github.com/chargome) in [#909](getsentry/sentry-javascript-bundler-plugins#909) - (tests) Use deterministic debugids by [@chargome](https://github.com/chargome) in [#912](getsentry/sentry-javascript-bundler-plugins#912) - Add esbuild integration tests by [@timfish](https://github.com/timfish) in [#911](getsentry/sentry-javascript-bundler-plugins#911) - Vite integration tests by [@timfish](https://github.com/timfish) in [#899](getsentry/sentry-javascript-bundler-plugins#899) - Webpack integration tests by [@timfish](https://github.com/timfish) in [#904](getsentry/sentry-javascript-bundler-plugins#904) - Isolate integration test package installs by [@timfish](https://github.com/timfish) in [#902](getsentry/sentry-javascript-bundler-plugins#902) - Pin GitHub Actions to full-length commit SHAs by [@joshuarli](https://github.com/joshuarli) in [#900](getsentry/sentry-javascript-bundler-plugins#900) - Rollup integration tests by [@timfish](https://github.com/timfish) in [#897](getsentry/sentry-javascript-bundler-plugins#897) - New integration tests by [@timfish](https://github.com/timfish) in [#896](getsentry/sentry-javascript-bundler-plugins#896) - Remove lerna by [@timfish](https://github.com/timfish) in [#895](getsentry/sentry-javascript-bundler-plugins#895) - Migrate to Vitest by [@timfish](https://github.com/timfish) in [#894](getsentry/sentry-javascript-bundler-plugins#894)
This file contains hidden or bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
Sign up for free
to join this conversation on GitHub.
Already have an account?
Sign in to comment
Add this suggestion to a batch that can be applied as a single commit.This suggestion is invalid because no changes were made to the code.Suggestions cannot be applied while the pull request is closed.Suggestions cannot be applied while viewing a subset of changes.Only one suggestion per line can be applied in a batch.Add this suggestion to a batch that can be applied as a single commit.Applying suggestions on deleted lines is not supported.You must change the existing code in this line in order to create a valid suggestion.Outdated suggestions cannot be applied.This suggestion has been applied or marked resolved.Suggestions cannot be applied from pending reviews.Suggestions cannot be applied on multi-line comments.Suggestions cannot be applied while the pull request is queued to merge.Suggestion cannot be applied right now. Please check back later.

This PR adds new more complete integration tests for Vite 4, 7 and 8.
diff --git a/packages/integration-tests-next/fixtures/vite4/utils.ts b/packages/integration-tests-next/fixtures/vite4/utils.ts
--- a/packages/integration-tests-next/fixtures/vite4/utils.ts
+++ b/packages/integration-tests-next/fixtures/vite4/utils.ts
@@ -26,8 +26,8 @@
// Clear the output directory before running the test
rmSync(outDir, { recursive: true, force: true });
- // Vite v8 requires Node 20+
- if (NODE_MAJOR_VERSION < 20) {
+ // Vite v4 requires Node 14.18+
+ if (NODE_MAJOR_VERSION < 14) {
// eslint-disable-next-line @typescript-eslint/no-empty-function
vitestTest.skip(testName);
} else {